@@ -31,7 +31,10 @@ def file_types(source_file, config):
                 if fnmatch(file_name, pattern):
                     config['type'] = node_type
                     return config
-    return
+        if not config.get('default_type', None):
+            return None
+        config['type'] = config['default_type']
+        return config
 
 
 def merge_files_config(source_file, config):
@@ -95,6 +98,17 @@ def setdefault_target_name(source_file, config):
     return config
 
 
+@provides('is_index')
+def setdefault_is_index(source_file, config):
+    ##|  ASSIGN DEFAULT NAME
+
+    config['is_index'] = False
+    if os.path.isfile(source_file):
+        if config['target_name'] == config['index.html'] and hasattr(config, 'parent'):
+            config['is_index'] = True
+    return config
+
+
 def folder_config_file(source_file, config):
     if config['type'] == 'folder':
         # the config is read *before* its processor is invoked (so no matter what processor you
@@ -113,7 +127,7 @@ def folder_config_file(source_file, config):
 
 
 def front_matter_config(source_file, config):
-    if config['type'] == 'page':
+    if config['type'] == 'page' and os.path.isfile(source_file):
         with open(source_file, 'r') as f:
             contents = f.read()
             front_config_match = re.match(r"\A([`]{3,})$", contents, re.MULTILINE)
@@ -232,7 +246,10 @@ def title_from_name(source_file, config):
     Title-cases the name and stores it in config['title']
     """
     if os.path.isfile(source_file):
-        title = config['name']
+        if config['is_index'] and hasattr(config, 'parent'):
+            title = config.parent.name
+        else:
+            title = config['name']
         title = title.replace('_', ' ')
         title = titlecase(title)
         config['title'] = title
